/**
 * Copyright (c) 2016-2019 人人开源 All rights reserved.
 *
 * https://www.renren.io
 *
 * 版权所有，侵权必究！
 */

package com.huijy.framework.resolver;

import com.huijy.common.annotation.LoginMember;
import com.huijy.framework.interceptor.MemberAuthorizationInterceptor;
import com.huijy.management.domain.Member;
import com.huijy.management.service.IMemberService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.MethodParameter;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.support.WebDataBinderFactory;
import org.springframework.web.context.request.NativeWebRequest;
import org.springframework.web.context.request.RequestAttributes;
import org.springframework.web.method.support.HandlerMethodArgumentResolver;
import org.springframework.web.method.support.ModelAndViewContainer;

/**
 * 有@LoginMember注解的方法参数，注入当前登录会员信息
 *
 * @author luobo
 */
@Component
public class LoginMemberHandlerMethodArgumentResolver implements HandlerMethodArgumentResolver {
    @Autowired
    private IMemberService memberService;

    @Override
    public boolean supportsParameter(MethodParameter parameter) {
        return parameter.getParameterType().isAssignableFrom(Member.class) && parameter.hasParameterAnnotation(LoginMember.class);
    }

    @Override
    public Object resolveArgument(MethodParameter parameter, ModelAndViewContainer container,
                                  NativeWebRequest request, WebDataBinderFactory factory) throws Exception {
        //获取会员ID
        Object object = request.getAttribute(MemberAuthorizationInterceptor.MEMBER_KEY, RequestAttributes.SCOPE_REQUEST);
        if(object == null){
            return null;
        }
        //获取用户信息
        Member member = memberService.selectMemberByMemberId((Long)object);

        if (member == null){
            return null;
        }
        return member;
    }
}
