package com.huijy.management.service.impl;

import java.util.Date;
import java.util.List;
import java.util.Map;

import com.huijy.common.exception.ServiceException;
import com.huijy.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.huijy.management.mapper.ContentMapper;
import com.huijy.management.domain.Content;
import com.huijy.management.service.IContentService;

/**
 * 内容管理Service业务层处理
 *
 * @author luobo
 * @date 2021-09-12
 */
@Service
public class ContentServiceImpl implements IContentService
{
    @Autowired
    private ContentMapper contentMapper;

    /**
     * 查询内容管理
     *
     * @param contentId 内容管理主键
     * @return 内容管理
     */
    @Override
    public Content selectContentByContentId(Long contentId)
    {
        Content content = contentMapper.selectContentByContentId(contentId);
        /**
         * 最调用一次，就加一
         */
        contentMapper.updateBrowseNumById(contentId);
        return content;
    }

    /**
     * 查询内容管理列表
     *
     * @param content 内容管理
     * @return 内容管理
     */
    @Override
    public List<Content> selectContentList(Content content)
    {
        return contentMapper.selectContentList(content);
    }

    /**
     * 新增内容管理
     *
     * @param content 内容管理
     * @return 结果
     */
    @Override
    public int insertContent(Content content)
    {
        content.setCreateTime(DateUtils.getNowDate());
        content.setAuditFlag("0");
        content.setReleaseFlag("0");
        content.setBrowseNum(0);
        return contentMapper.insertContent(content);
    }

    /**
     * 修改内容管理
     *
     * @param content 内容管理
     * @return 结果
     */
    @Override
    public int updateContent(Content content)
    {
        return contentMapper.updateContent(content);
    }

    /**
     * 批量删除内容管理
     *
     * @param contentIds 需要删除的内容管理主键
     * @return 结果
     */
    @Override
    public int deleteContentByContentIds(Long[] contentIds)
    {
        return contentMapper.deleteContentByContentIds(contentIds);
    }

    /**
     * 删除内容管理信息
     *
     * @param contentId 内容管理主键
     * @return 结果
     */
    @Override
    public int deleteContentByContentId(Long contentId)
    {
        return contentMapper.deleteContentByContentId(contentId);
    }

    public Integer updateAudit(Long contentId,String auditFlag,String auditMsg,Long adminId){

        //auditFlag 审核状态 0、未审核 1初审 2终审

        Content content = contentMapper.selectContentByContentId(contentId);
        if (content==null){
            throw new ServiceException("内容信息为空");
        }
        if (content.getReleaseFlag().equalsIgnoreCase("1")){
            throw new ServiceException("内容已发布，不能审核/反审核操作");
        }
        if (content.getAuditFlag().equalsIgnoreCase("0") && auditFlag.equalsIgnoreCase("2")){

                throw new ServiceException("内容未初审，不能终审操作");

        }
        if (content.getAuditFlag().equalsIgnoreCase("2") && auditFlag.equalsIgnoreCase("1")){
            throw new ServiceException("内容已终审，不能初审操作");
        }
        content.setAuditFlag(auditFlag);
        if(auditFlag.equalsIgnoreCase("1")){
            content.setAuditAt(adminId);
            content.setAuditTime(new Date());
            content.setAuditMsg(auditMsg);
        }else if(auditFlag.equalsIgnoreCase("2")){
            content.setEndAuditAt(adminId);
            content.setEndAuditTime(new Date());
            content.setEndAuditMsg(auditMsg);
        }
      return   updateContent(content);

    }

    @Override
    public Integer updateRelease(Long contentId, String releaseFlag, Long adminId) {
        //auditFlag 审核状态 0、未审核 1初审 2终审

        Content content = contentMapper.selectContentByContentId(contentId);
        if (content==null){
            throw new ServiceException("内容信息为空");
        }
        if (!content.getAuditFlag().equalsIgnoreCase("2")){
            throw new ServiceException("内容未终审，不能发布核操作");
        }
        content.setReleaseFlag(releaseFlag);
        if (releaseFlag.equalsIgnoreCase("1")){
            content.setReleaseAt(adminId);
            content.setReleaseTime(new Date());
        }
        return   updateContent(content);
    }

    @Override
    public List<Map<String, Object>> home() {
        return contentMapper.home();
    }
}
